/*
* Copyright 2011 the original author or authors.
*
* Licensed under the Apache License, Version 2.0 (the "License"); you may not
* use this file except in compliance with the License. You may obtain a copy of
* the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
* WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
* License for the specific language governing permissions and limitations under
* the License.
*/

package com.github.javarch.jsf;

import java.util.ArrayList;
import java.util.List;

import org.jmock.Expectations;
import org.jmock.auto.Mock;
import org.jmock.integration.junit4.JUnitRuleMockery;
import org.jmock.lib.legacy.ClassImposteriser;
import org.junit.Assert;
import org.junit.Rule;
import org.junit.Test;
import org.primefaces.model.SortOrder;

import com.github.javarch.persistence.PageRequest;
import com.github.javarch.persistence.Repository;
import com.github.javarch.persistence.orm.hibernate.AbstractPersistable;

/**
 * 
 * @author Lucas
 *
 */
public class GenericLazyDataModelTest {
	
	@Rule
	public final JUnitRuleMockery ctx = new JUnitRuleMockery(){{
		setImposteriser(ClassImposteriser.INSTANCE);
	}};
	
	@Mock Repository repository;

	private GenericLazyDataModel<Pessoa> instance;

	@Test
	public void testPageRequest() {
		final PageRequest pr = new PageRequest(10, 15);
		final List<Pessoa> pessoas =  buildList(15);
		
		ctx.checking(new Expectations(){{
			oneOf( repository ).findAll(Pessoa.class, pr ); will( returnValue( pessoas ) );
			oneOf( repository ).count(Pessoa.class); will(returnValue(50L));
		}});
		
		instance = new GenericLazyDataModel<Pessoa>(repository, Pessoa.class);
		
		List<Pessoa> result = instance.load(10, 15, "name", SortOrder.UNSORTED , null);
		
		ctx.assertIsSatisfied();
		
		Assert.assertEquals( pessoas, result );
		Assert.assertEquals( 15, result.size());
		Assert.assertEquals( 50, instance.getRowCount() );		
	}
	
	protected List<Pessoa> buildList(int size){
		Assert.assertTrue( size >= 0 );
		List<Pessoa> list = new ArrayList<GenericLazyDataModelTest.Pessoa>(size);
		
		for( int i = 0 ; i < size ; i++ ){
			list.add( new Pessoa() );
		}	
		return list;
	}
	
	class Pessoa extends AbstractPersistable {		
	}

}
