package com.github.javarch.persistence.aop;

import javax.inject.Inject;

import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.core.env.Environment;
import org.springframework.stereotype.Component;

import com.github.javarch.support.log.Logger;
import com.github.javarch.support.log.Logging;
import com.github.javarch.support.spring.Profiles;
import com.yammer.metrics.core.MetricsRegistry;
import com.yammer.metrics.core.Timer;
import com.yammer.metrics.core.TimerContext;

@Aspect
public class JavarchPersistenceTimerProfiling implements InitializingBean {

	@Logging
	private Logger logger;
	
	@Inject
	private MetricsRegistry registry;
	
	@Inject
	private Environment enviroment;
	
	private Timer timer;
	
	private boolean profiling;
	
    @Pointcut("execution(* com.github.javarch.persistence.orm.hibernate.HibernateRepository.*(..))")
    private void anyOperationInHibernateRepository() {
        /* nothing to do here;
         * this just defines that we want to catch all methods
         * in the controller-package
         */
    }
	
	@Around("anyOperationInHibernateRepository()")
	public Object profilingTimer( ProceedingJoinPoint pjp ) throws Throwable {
		
		logger.info("Profiling: {}", pjp.getSignature().getName() );
		
		TimerContext context = null;
		
		try {
			if ( profiling ){
				context = timer.time();			
			}	
			return pjp.proceed();
		}finally {
			if( profiling ){
				context.stop();
			}
		}
		
	}
	
	@Override
	public void afterPropertiesSet() throws Exception {
		logger.debug("Inicializando {}", getClass().getSimpleName() );
		timer =  registry.newTimer( JavarchPersistenceTimerProfiling.class, "persistence-time", "database" );
		profiling = enviroment.acceptsProfiles( Profiles.PROFILING ); 
	}
}
