package com.github.javarch.support.spring;

import java.lang.reflect.Method;
import java.util.List;

import org.springframework.beans.BeansException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.config.BeanPostProcessor;

import com.github.javarch.support.annotations.MethodAnnotationUtils;
import com.github.javarch.support.log.Logger;
import com.github.javarch.support.log.LoggerFactory;
import com.google.common.eventbus.EventBus;
import com.google.common.eventbus.Subscribe;

public class EventBusRegisterBeanPostProcessor implements BeanPostProcessor {
    
    @Autowired
    private EventBus eventBus;
    
	private final Logger log = LoggerFactory.getLogger(this.getClass());
    
    @Override
    public Object postProcessBeforeInitialization(Object bean, String beanName) throws BeansException {
        return bean;
    }

    @Override
    public Object postProcessAfterInitialization(Object bean, String beanName) throws BeansException {
    	 
    	List<Method> methods = MethodAnnotationUtils.findMethodsWithAnnotation(bean.getClass(), Subscribe.class);

    	if ( methods.isEmpty() ){
    		return bean;
    	}
    	
        // register it with the event bus
        eventBus.register(bean);
        log.trace("Bean {} containing methods that was subscribed to {}",
            new Object[] { beanName,  EventBus.class.getCanonicalName()   });
                
        return bean;
    }
    
}